use rocket::serde::Serialize;

#[derive(Serialize, Clone)]
#[serde(crate = "rocket::serde")]
pub struct Course {
    pub course_id: i32,
    /// Display code, shown on the certificate.
    /// Currently a 4-digit number. After 9999, it will be a 4-digit hex number.
    ///
    /// Example: `0322`
    pub course_code: i32,
    /// Internal name, shown in the admin panel
    ///
    /// Example: `4x4`
    pub course_name: String,
    /// Display name, partially shown on the certificate & public page
    ///
    /// Example: `Manejo en 4x4 road danger`
    pub course_display_name: String,
    /// Number of days of the course.
    /// Used to calculate how to space the courses
    /// 
    /// Example: `2`
    pub course_days_amount: i32,
    /// Whether the course name can be extended with a label.
    /// Used in machinery courses, where the course name is the type of machinery,
    /// and the custom label the manufacturer and series (i.e. `320D CAT`).
    pub course_has_custom_label: bool,
}
